# Secure Application With AI

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 

[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   [![Python 3.8](https://img.shields.io/badge/python-3.8-yellow.svg)](https://www.python.org/downloads/release/python-380/)   


## Functionality of the vibeAI2

- Better Looking With AI  
- Block unauthorized  user 
- Authorized user can Allow

## Usage

- Make sure you have Python installed in your system.
- Run Following command in the CMD.
 ```
  pip install vibeAI24
  ```
## Example

 ```
# test.py
from src.vibeAI24 import data_breache, predict_breach

  ```

## Run the following Script.
 ```
  python test.py
 ```



## Note 
- I have tried to implement all the functionality, it might have some bugs also. Ignore that or please try to solve that bug.
